==> externalVector_1.0.3.tar.gz: externalVector/man/externalVector-class.Rd <==
\name{externalVector-class}
\docType{class}
\alias{externalVector-class}
\alias{asEach,externalVector,character-method}
\alias{c,externalVector-method}
\alias{apply,externalVector-method}
\alias{as.complex,externalVector-method}
\alias{as.data.frame,externalVector-method}
\alias{as.double,externalVector-method}
\alias{as.integer,externalVector-method}
\alias{as.list,externalVector-method}
\alias{as.logical,externalVector-method}
\alias{as.matrix,externalVector-method}
\alias{as.numeric,externalVector-method}
\alias{as.single,externalVector-method}
\alias{coerce,externalVector,vector-method}
\alias{coerce,externalVector,matrix-method}
\alias{coerce,vector,externalVector-method}
\alias{coerce,matrix,externalVector-method}
\alias{defaultElement,externalVector-method}
\alias{dimnames<-,externalVector,NULL-method}
\alias{dimnames<-,externalVector,list-method}
\alias{names<-,externalVector,externalVector-method}
\alias{names<-,externalVector,ANY-method}
\alias{names<-,externalVector,NULL-method}
\alias{setDimNames,externalVector-method}
\alias{setNames,externalVector-method}
\alias{show,externalVector-method}
\alias{as.character,externalVector-method}
\alias{as.Rvector,externalVector-method}
\alias{as.vector,externalVector-method}
\alias{lapply,externalVector-method}
\alias{sapply,externalVector-method}
\alias{mean,externalVector-method}
\alias{median,externalVector-method}

\title{Class "externalVector", base class for vector objects stored in
  an external resource }
\description{ This class represents objects that behave like R basic
  vectors but are stored in some external resource. }
\section{Objects from the Class}{A virtual Class: No objects may be created from it.}
\section{Methods}{
  Common signature components for the methods:

  \tabular{ll}{
    x \tab The class "externalVector"\cr
    X \tab The class "externalVector"\cr
  }

  Description of the methods:
  
  \describe{
    \item{asEach(x, type, arrayOnly)}{ Coerce \code{x} so that it now
      behaves like a basic R vector with the same class as \code{type}.}
    \item{c(x, \dots, recursive)}{ Combine all the arguments into a
      single vector. }
      behaves like a basic R vector with the same class as \code{type}.}
    \item{as.Rvector(x)}{ Coerce \code{x} to a basic R vector with same
      names, dimension and dimnames (if any of these are present in
      \code{x}). }
    \item{as.vector(x, mode)}{ Return an external vector which behaves
      like a basic R vector of mode \code{mode}. }
    \item{as.logical(x, \dots)}{ Return an external vector with all
      elements coerced to logical. }
    \item{as.integer(x, \dots)}{ Return an external vector with all
      elements coerced to integer. }
    \item{as.double(x, \dots)}{ Return an external vector with all
      elements coerced to numeric. }
    \item{as.numeric(x, \dots)}{ Return an external vector with all
      elements coerced to numeric. }
    \item{as.charcater(x)}{ Return an external vector with all
      elements coerced to character. }
    \item{as.list(x, \dots)}{ Return an external vector that behaves like
      a list. }
    \item{as.single(x, \dots)}{ Return an external vector with all
      elements coerced to numeric and a "CSingle" attribute set to
      \code{TRUE}. }
    \item{as.data.frame(x, row.names, optional}{ Create a data.frame
      object from \code{x}. }
    \item{as.matrix(x)}{ If \code{length(dim(x))} is \code{2}, return
      \code{x} unchanged. Otherwise, return \code{x} as a matrix with a
      single column. }
    \item{defaultElement(x)}{ The default element of \code{x} contained
      in a basic R vector. }
    \item{dimnames(x) <- value}{ Set dimnames of \code{x} to value. }
    \item{names(x) <- value}{ Set names of \code{x} to value. }
    \item{show(object)}{ Display \code{object}. }
    \item{apply(X, MARGIN, FUN, \dots}{ Coerce X to an R matrix and call
      the default \code{apply} method. }
    \item{lapply(X, FUN, \dots)}{ Lapply for "externalVector"
      class. }
    \item{sapply(X, FUN, \dots, simplify, USE.NAMES)}{ Sapply for
      "externalVector" class. }
    \item{mean(x, trim = 0, na.rm = FALSE, \dots)}{ Mean and trimmed
      mean of \code{x}. }
    \item{median(x, na.rm = FALSE)}{ Mean of \code{x}. }
  }
}
\section{Virtual Methods}{
  Common signature components for implementation of the virtual methods:

  \tabular{ll}{
    x \tab A subclass of "externalVector"\cr
    value \tab The class "ANY"\cr
  }

  Description of the virtual methods:
  
  \describe{
    \item{setDimNames(x, value)}{ Set the dimnames of \code{x} to
      \code{value} without any error checking or coercion. Return the
      modified \code{x}. }
    \item{setNames(x, value)}{ Set the names of \code{x} to \code{value}
      without any error checking or coercion. Return the modified
      \code{x}. }
  }
}
\seealso{
  \code{\link{externalVectorWithStorage-class}},\code{\link{matrixIndex-class}},
  \code{\link{indirectExternalVector-class}},
  \code{\link{indirectExternalMatrix-class}}, for subclasses of
  \code{"externalVector"}.
}
\keyword{classes}

==> externalVector_1.4.0.tar.gz: externalVector/man/externalVector-class.Rd <==
\name{externalVector-class}
\docType{class}
\alias{externalVector-class}
\alias{asEach,externalVector,character-method}
\alias{c,externalVector-method}
\alias{apply,externalVector-method}
\alias{as.complex,externalVector-method}
\alias{as.data.frame,externalVector-method}
\alias{as.double,externalVector-method}
\alias{as.integer,externalVector-method}
\alias{as.list,externalVector-method}
\alias{as.logical,externalVector-method}
\alias{as.matrix,externalVector-method}
\alias{as.numeric,externalVector-method}
\alias{as.single,externalVector-method}
\alias{coerce,externalVector,vector-method}
\alias{coerce,externalVector,matrix-method}
\alias{coerce,vector,externalVector-method}
\alias{coerce,matrix,externalVector-method}
\alias{defaultElement,externalVector-method}
\alias{dimnames<-,externalVector,NULL-method}
\alias{dimnames<-,externalVector,list-method}
\alias{names<-,externalVector,externalVector-method}
\alias{names<-,externalVector,ANY-method}
\alias{names<-,externalVector,NULL-method}
\alias{setDimNames,externalVector-method}
\alias{setNames,externalVector-method}
\alias{show,externalVector-method}
\alias{as.character,externalVector-method}
\alias{as.Rvector,externalVector-method}
\alias{as.vector,externalVector-method}
\alias{lapply,externalVector-method}
\alias{sapply,externalVector-method}
\alias{mean,externalVector-method}
\alias{median,externalVector,ANY-method}
\alias{median,externalVector,missing-method}
\alias{cor,ANY,externalVector-method}
\alias{cov,ANY,externalVector-method}
\alias{var,ANY,externalVector-method}
\alias{cor,externalVector,ANY-method}
\alias{cov,externalVector,ANY-method}
\alias{var,externalVector,ANY-method}
\alias{cov2cor,externalVector-method}

\title{Class "externalVector", base class for vector objects stored in
  an external resource }
\description{ This class represents objects that behave like R basic
  vectors but are stored in some external resource. }
\section{Objects from the Class}{A virtual Class: No objects may be created from it.}
\section{Methods}{
  Common signature components for the methods:

  \tabular{ll}{
    x \tab The class "externalVector"\cr
    X \tab The class "externalVector"\cr
  }

  Description of the methods:
  
  \describe{
    \item{asEach(x, type, arrayOnly)}{ Coerce \code{x} so that it now
      behaves like a basic R vector with the same class as \code{type}.}
    \item{c(x, \dots, recursive)}{ Combine all the arguments into a
      single vector. }
      behaves like a basic R vector with the same class as \code{type}.}
    \item{as.Rvector(x)}{ Coerce \code{x} to a basic R vector with same
      names, dimension and dimnames (if any of these are present in
      \code{x}). }
    \item{as.vector(x, mode)}{ Return an external vector which behaves
      like a basic R vector of mode \code{mode}. }
    \item{as.logical(x, \dots)}{ Return an external vector with all
      elements coerced to logical. }
    \item{as.integer(x, \dots)}{ Return an external vector with all
      elements coerced to integer. }
    \item{as.double(x, \dots)}{ Return an external vector with all
      elements coerced to numeric. }
    \item{as.numeric(x, \dots)}{ Return an external vector with all
      elements coerced to numeric. }
    \item{as.charcater(x)}{ Return an external vector with all
      elements coerced to character. }
    \item{as.list(x, \dots)}{ Return an external vector that behaves like
      a list. }
    \item{as.single(x, \dots)}{ Return an external vector with all
      elements coerced to numeric and a "CSingle" attribute set to
      \code{TRUE}. }
    \item{as.data.frame(x, row.names, optional}{ Create a data.frame
      object from \code{x}. }
    \item{as.matrix(x)}{ If \code{length(dim(x))} is \code{2}, return
      \code{x} unchanged. Otherwise, return \code{x} as a matrix with a
      single column. }
    \item{defaultElement(x)}{ The default element of \code{x} contained
      in a basic R vector. }
    \item{dimnames(x) <- value}{ Set dimnames of \code{x} to value. }
    \item{names(x) <- value}{ Set names of \code{x} to value. }
    \item{show(object)}{ Display \code{object}. }
    \item{apply(X, MARGIN, FUN, \dots}{ Coerce X to an R matrix and call
      the default \code{apply} method. }
    \item{lapply(X, FUN, \dots)}{ Lapply for "externalVector"
      class. }
    \item{sapply(X, FUN, \dots, simplify, USE.NAMES)}{ Sapply for
      "externalVector" class. }
    \item{mean(x, trim = 0, na.rm = FALSE, \dots)}{ Mean and trimmed
      mean of \code{x}. }
    \item{median(x, na.rm = FALSE)}{ Mean of \code{x}. }
  }
}
\section{Virtual Methods}{
  Common signature components for implementation of the virtual methods:

  \tabular{ll}{
    x \tab A subclass of "externalVector"\cr
    value \tab The class "ANY"\cr
  }

  Description of the virtual methods:
  
  \describe{
    \item{setDimNames(x, value)}{ Set the dimnames of \code{x} to
      \code{value} without any error checking or coercion. Return the
      modified \code{x}. }
    \item{setNames(x, value)}{ Set the names of \code{x} to \code{value}
      without any error checking or coercion. Return the modified
      \code{x}. }
  }
}
\seealso{
  \code{\link{externalVectorWithStorage-class}},\code{\link{matrixIndex-class}},
  \code{\link{indirectExternalVector-class}},
  \code{\link{indirectExternalMatrix-class}}, for subclasses of
  \code{"externalVector"}.
}
\keyword{classes}
